#include <iostream>
#include <queue>

struct Edge {
    int32_t u, v, t;
};

const int32_t MAX_WEIGHT = 1e6;

int32_t find_ans(const int32_t n, const std::vector<Edge>& e) {
    const int32_t entrance = 0, orthanc = n - 1;

    // Dijkstra algorithm in m log n
    const int64_t INF = static_cast<int64_t>(n) * MAX_WEIGHT;
    std::vector<std::vector<int32_t>> ingoing_arc_indices(n);
    for (int32_t arc_index = 0; arc_index < std::ssize(e); ++arc_index)
        ingoing_arc_indices[e[arc_index].v].push_back(arc_index);
    std::vector<int64_t> distance_to_orthanc(n, INF);
    std::priority_queue<std::pair<int64_t, int32_t>, std::vector<std::pair<int64_t, int32_t>>, std::greater<>> nearest;
    nearest.emplace(0, orthanc);
    distance_to_orthanc[orthanc] = 0;
    while (!nearest.empty()) {
        auto [current_distance_to_orthanc, current_tower] = nearest.top();
        nearest.pop();
        if (current_distance_to_orthanc != distance_to_orthanc[current_tower])
            continue;
        for (int32_t arc_index : ingoing_arc_indices[current_tower]) {
            int32_t another_tower = e[arc_index].u;
            int64_t new_distance_to_orthanc = current_distance_to_orthanc + e[arc_index].t;
            if (new_distance_to_orthanc < distance_to_orthanc[another_tower]) {
                distance_to_orthanc[another_tower] = new_distance_to_orthanc;
                nearest.emplace(new_distance_to_orthanc, another_tower);
            }
        }
    }

    // 0-1-BFS for dividing the transport system into layers
    std::vector<int32_t> incompetence(n, n);
    std::deque<std::pair<int32_t, int32_t>> bfs_queue;
    for (int32_t tower_index = 0; tower_index < n; ++tower_index)
        if (distance_to_orthanc[tower_index] == INF) {
            incompetence[tower_index] = -1;
            bfs_queue.emplace_back(-1, tower_index);
        }
    while (!bfs_queue.empty()) {
        auto [current_incompetence, current_tower] = bfs_queue.front();
        bfs_queue.pop_front();
        if (current_incompetence != incompetence[current_tower])
            continue;
        for (int32_t arc_index : ingoing_arc_indices[current_tower]) {
            int32_t another_tower = e[arc_index].u;
            int64_t induced_distance_to_orthanc = distance_to_orthanc[current_tower] + e[arc_index].t;
            if (induced_distance_to_orthanc == distance_to_orthanc[another_tower]) {
                int32_t new_incompetence = current_incompetence;
                if (incompetence[another_tower] > new_incompetence) {
                    incompetence[another_tower] = new_incompetence;
                    bfs_queue.emplace_front(new_incompetence, another_tower);
                }
            } else {
                int32_t new_incompetence = current_incompetence + 1;
                if (incompetence[another_tower] > new_incompetence) {
                    incompetence[another_tower] = new_incompetence;
                    bfs_queue.emplace_back(new_incompetence, another_tower);
                }
            }
        }
    }
    return incompetence[entrance];
}

void solve_test() {
    int n, m;
    std::cin >> n >> m;
    std::vector<Edge> e(m);
    for (Edge& f : e) {
        std::cin >> f.u >> f.v >> f.t;
        --f.u;
        --f.v;
    }
    int32_t ans = find_ans(n, e);
    std::cout << ans << '\n';
}

int main() {
    solve_test();
}
