#include <iostream>
#include <iomanip>
#include <vector>
#include <deque>
#include <queue>
#include <string>
#include <set>
#include <map>
#include <numeric>
#include <algorithm>

using namespace std;

struct Vertex {
	vector<int> to;
	pair<int, int> p;
	int used = 0, id = 0, color = 0;
};

void topSort(int x, vector<Vertex>& g, vector<int>& list) {
	if (g[x].used++) return;
	for (auto y : g[x].to)
		topSort(y, g, list);
	list.push_back(x);
}

void dfs(int x, vector<Vertex>& g, vector<int>& right) {
	if (g[x].used++) return;
	if (!g[x].p.first && !g[x].p.second)
		right.push_back(x);

	for (auto y : g[x].to)
		dfs(y, g, right);
}

bool hasCircles(int x, vector<Vertex>& g) {
	if (g[x].color == 2) return false;
	if (g[x].color == 1) return true;
	g[x].color = 1;
	for (auto y : g[x].to)
		if (hasCircles(y, g))
			return true;
	g[x].color = 2;
	return false;
}

void F() {
	int n;
	cin >> n;

	vector<Vertex> g(n + 1);
	for (int i = 1; i < n + 1; i++) {
		string s1, s2;
		cin >> s1 >> s2;

		if (s1 == "set") g[i].p.first = 1;
		if (s2 == "true") g[i].p.second = 1;
		g[i].id = i;
	}

	int m;
	cin >> m;

	while (m--) {
		int x, y;
		cin >> x >> y;

		g[x].to.push_back(y);
	}

	int id1 = -1, id2 = -1;
	for (int i = 1; i < n + 1; i++) {
		if (!g[i].p.first && g[i].p.second) {
			id2 = i;
		}
		if (g[i].p.first && g[i].p.second) {
			id1 = i;
		}
	}

	for (int i = 1; i < n + 1; i++) {
		if (id1 != -1 && g[i].p.first && !g[i].p.second)
			g[id1].to.push_back(i);
		if (id1 == -1 && g[i].p.first && !g[i].p.second) {
			cout << -1 << '\n';
			return;
		}
		if (id2 != -1 && g[i].p.first && !g[i].p.second)
			g[i].to.push_back(id2);
		if (id1 != -1 && id2 == -1 && !g[i].p.first && !g[i].p.second)
			g[i].to.push_back(id1);
	}

	vector<int> ord;
	if (id1 == -1 && id2 == -1) {
		for (int i = 1; i < n + 1; i++)
			topSort(i, g, ord);
		reverse(ord.begin(), ord.end());

		for (auto x : ord)
			cout << x << '\n';
		return;
	}

	if (id1 == -1 && id2 != -1) {
		cout << -1 << '\n';
		return;
	}

	vector<int> left, right;
	dfs(id1, g, right);

	set<int> rightUsed;
	for (auto x : right) {
		if (id2 == -1) {
			cout << -1 << '\n';
			return;
		}
		g[id2].to.push_back(x);
		rightUsed.insert(x);
	}

	for (int i = 1; i < n + 1; i++)
		if (!g[i].p.first && !g[i].p.second && !rightUsed.count(i))
			g[i].to.push_back(id1);

	for (int i = 1; i < n + 1; i++)
		if (hasCircles(i, g)) {
			cout << -1 << '\n';
			return;
		}

	for (int i = 1; i < n + 1; i++)
		g[i].used = false;

	for (int i = 1; i < n + 1; i++)
		topSort(i, g, ord);
	reverse(ord.begin(), ord.end());
	for (auto x : ord)
		cout << x << ' ';
}

int main() {
#ifdef ROMA
	FILE* stream;
	freopen_s(&stream, "input.txt", "r", stdin);
	//freopen_s(&stream, "output.txt", "w", stdout);
#endif
	cin.tie(0)->sync_with_stdio(0);
	int t = 1;
	//cin >> t;
	while (t--)
		F();
}