#include <iostream>
#include <vector>
#include <algorithm>
#include <cmath>
#include <string>
#include <set>
#include <map>
#include <queue>

using namespace std;

using ll = long long;

struct NodeType {
    bool white;
    bool king;
};

queue<int> blackQueue, whiteQueue;
std::vector<NodeType> types;
int whiteKing = -1;
int blackKing = -1;
bool whiteCanTake = false;
bool blackCanTake = false;

void addToQueue(int i) {
    if (types[i].white) {
        if (i == whiteKing) {
            whiteCanTake = true;
        } else {
            whiteQueue.push(i);
        }
    } else {
        if (i == blackKing) {
            blackCanTake = true;
        } else {
            blackQueue.push(i);
        }
    }
}

int main() {
    int n;
    std::cin >> n;
    for (int i = 0; i < n; ++i) {
        string type, result;
        std::cin >> type >> result;
        if (type == "set" && result == "false") {
            types.push_back({true, false});
        } else if (type == "unset" && result == "false") {
            types.push_back({false, false});
        } else if (type == "unset" && result == "true") {
            types.push_back({true, true});
            if (whiteKing != -1) {
                std::cout << -1 << std::endl;
                return 0;
            }
            whiteKing = i;
        } else if (type == "set" && result == "true") {
            types.push_back({false, true});
            if (blackKing != -1) {
                std::cout << -1 << std::endl;
                return 0;
            }
            blackKing = i;
        }
    }
    if (whiteKing != -1 && blackKing == -1) {
        std::cout << -1 << std::endl;
        return 0;
    }

    int m;
    std::cin >> m;
    std::vector<std::vector<int>> edges(n);
    std::vector<int> inEdges(n);
    int freeCount = 0;
    for (int i = 0; i < m; ++i) {
        int x, y;
        std::cin >> x >> y;
        --x;
        --y;
        edges[x].push_back(y);
        ++inEdges[y];
    }
    for (int i = 0; i < inEdges.size(); ++i) {
        if (inEdges[i] == 0) {
            addToQueue(i);
        }
    }
    vector<int> ans;
    while(!blackQueue.empty()) {
        int current = blackQueue.front();
        blackQueue.pop();
        ans.push_back(current + 1);
        ++freeCount;
        for (auto next : edges[current]) {
            inEdges[next]--;
            if (inEdges[next] == 0) {
                addToQueue(next);
            }
        }
    }
    if (freeCount == n) {
        for (auto x : ans) {
            std::cout << x << ' ';
        }
        cout << endl;
        return 0;
    }
    if (!blackCanTake) {
        cout << -1 << endl;
        return 0;
    }
    freeCount++;
    ans.push_back(blackKing + 1);
    for (auto next : edges[blackKing]) {
        inEdges[next]--;
        if (inEdges[next] == 0) {
            addToQueue(next);
        }
    }
    while(!whiteQueue.empty()) {
        int current = whiteQueue.front();
        whiteQueue.pop();
        ans.push_back(current + 1);
        ++freeCount;
        for (auto next : edges[current]) {
            inEdges[next]--;
            if (inEdges[next] == 0) {
                addToQueue(next);
            }
        }
    }
    if (freeCount == n) {
        for (auto x : ans) {
            std::cout << x << ' ';
        }
        cout << endl;
        return 0;
    }
    if (!whiteCanTake) {
        cout << -1 << endl;
        return 0;
    }
    freeCount++;
    ans.push_back(whiteKing + 1);
    for (auto next : edges[whiteKing]) {
        inEdges[next]--;
        if (inEdges[next] == 0) {
            addToQueue(next);
        }
    }
    while(!blackQueue.empty()) {
        int current = blackQueue.front();
        blackQueue.pop();
        ans.push_back(current + 1);
        ++freeCount;
        for (auto next : edges[current]) {
            inEdges[next]--;
            if (inEdges[next] == 0) {
                addToQueue(next);
            }
        }
    }
    if (freeCount == n) {
        for (auto x: ans) {
            cout << x << ' ';
        }
        cout << endl;
    } else {
        cout << -1 << endl;
    }
}
