#include <bits/stdc++.h>

using namespace std;

using ii = __int128;
using ll = long long;

struct F {
    ll a{0}, b{0};

    explicit F(ll a = 0, ll b = 0) : a(a), b(b) {}

    F operator+(const F& f) const {
        return F(a + f.a, b + f.b);
    }

    F operator-(const F& f) const {
        return F(a - f.a, b - f.b);
    }

    friend ostream& operator<<(ostream& os, const F& x) {
        os << x.a;
        if (x.b >= 0) os << '+';
        os << x.b << "w";
        return os;
    }
};

bool operator==(F a, F b) {
    return a.a == b.a && a.b == b.b;
}

bool operator<(F a, F b) {
    a = a - b;
    ll x = a.a, y = a.b;
    y *= -1;
    if (x >= 0 && y <= 0) {
        return false;
    }
    if (x < 0 && y >= 0) {
        return true;
    }
    ii val = x * (ii) x  - y * (ii) y * 2;
    if (x >= 0) {
        return val < 0;
    }
    return val > 0;
}

struct Point {
    F x, y;

//    Point() = default;

    explicit Point(F x = F(0, 0), F y = F(0, 0)) : x(x), y(y) {}

    Point operator+(Point f) {
        return Point(x + f.x, y + f.y);
    }

    Point operator-(Point f) {
        return Point(x - f.x, y - f.y);
    }

    friend ostream& operator<<(ostream& os, const Point& pt) {
        return os << "(" << pt.x << ", " << pt.y << ")";
    }
};

bool operator==(Point a, Point b) {
    return a.x == b.x && a.y == b.y;
}

bool operator<(Point a, Point b) {
    if (a.x < b.x) return true;
    if (b.x < a.x) return false;
    return a.y < b.y;
}

struct Seg {
    Point l, r;
    int dir;

    Seg(Point l = Point(), Point r = Point(), int dir = 0) : l(l), r(r), dir(dir) {}

    F Orth() const {
        if (dir == 0) return l.y;
        if (dir == 1) return l.y - l.x;
        if (dir == 2) return l.x;
        if (dir == 3) return l.y + l.x;
        return F();
    }
};

F DotDirection(const Point& l, int dir) {
    return dir == 0 ? l.x : l.y;
}

vector<pair<Point, Point>> update(vector<Seg>& a) {
    vector<Point> b;
    for (auto& seg : a) {
        b.push_back(seg.l);
        b.push_back(seg.r);
        if (seg.r < seg.l) swap(seg.l, seg.r);
    }
    std::sort(b.begin(), b.end());
    for (auto& seg : a) {
        seg.l = seg.l - b[0];
        seg.r = seg.r - b[0];
    }
    vector<vector<Seg>> sex(4);
    for (auto& seg : a) {
        sex[seg.dir].push_back(seg);
    }

    vector<pair<Point, Point>> res;

    for (int dir = 0; dir < 4; dir++) {
        auto& w = sex[dir];
        sort(w.begin(), w.end(), [&](auto& lhs, auto& rhs) {
            return lhs.Orth() < rhs.Orth();
        });

        const int n = w.size();
        for (int r = 0; r < n; ) {
            int l = r;
            while (r < n && w[l].Orth() == w[r].Orth()) ++r;

            vector<pair<Point, int>> events;
            for (int i = l; i != r; ++i) {
                auto a = w[i].l, b = w[i].r;
                if (DotDirection(b, dir) < DotDirection(a, dir))
                    swap(a, b);
                events.emplace_back(a, +1);
                events.emplace_back(b, -1);
            }

            sort(events.begin(), events.end(), [&](const auto& lhs, const auto& rhs) {
                auto dlhs = DotDirection(lhs.first, dir);
                auto drhs = DotDirection(rhs.first, dir);
                if (dlhs == drhs) {
                    return lhs.second > rhs.second;
                } else {
                    return dlhs < drhs;
                }
//                return DotDirection(lhs.first, dir) < DotDirection(rhs.first, dir);
            });

            int lvl = 0;
            Point start;
            for (auto [pt, dh] : events) {
                if (dh > 0) {
                    if (lvl == 0) start = pt;
                    lvl += dh;
                } else {
                    lvl += dh;
                    if (lvl == 0) {
                        res.emplace_back(start, pt);
                    }
                }
            }
        }
    }
    std::sort(res.begin(), res.end());
    for (auto& [a, b] : res) {
        if (b < a) swap(a, b);
    }
    return res;
//    for (auto [x, y] : a) {
//        cout << x.x.a << " " << x.x.b << " " << x.y.a << " " << x.y.b << endl;
//        cout << y.x.a << " " << y.x.b << " " << y.y.a << " " << y.y.b << endl;
//    }
}

void solve() {
    int n;
    cin >> n;
    vector<pair<string, int>> cmd(n);
    vector<array<int, 4>> d = {{0, 1, 0, 0},
                               {1, 0, 1, 0},
                               {0, 0, 0, 1},
                               {-1, 0, 1, 0},
                               {0, -1, 0, 0},
                               {-1, 0, -1, 0},
                               {0, 0, 0, -1},
                               {1, 0, -1, 0}};
    int dir = 0;
    vector<Seg> have;
    Point pt;
    for (auto& [s, x] : cmd) {
        cin >> s >> x;
        if (s == "rotate") {
            dir = (dir + x / 45) % 8;
        } else if (s == "move") {
            pt.x.a += x * d[dir][0];
            pt.x.b += x * d[dir][1];
            pt.y.a += x * d[dir][2];
            pt.y.b += x * d[dir][3];
        } else {
            have.push_back({pt, pt, dir % 4});
            pt.x.a += x * d[dir][0];
            pt.x.b += x * d[dir][1];
            pt.y.a += x * d[dir][2];
            pt.y.b += x * d[dir][3];
            have.back().r = pt;
        }
    }
    for (int j = 45; j <= 360; j += 45) {
        dir = (j / 45) % 8;
        vector<Seg> have2;
        Point pt;
        for (auto& [s, x] : cmd) {
//            cin >> s >> x;
            if (s == "rotate") {
                dir = (dir + x / 45) % 8;
            } else if (s == "move") {
                pt.x.a += x * d[dir][0];
                pt.x.b += x * d[dir][1];
                pt.y.a += x * d[dir][2];
                pt.y.b += x * d[dir][3];
            } else {
                have2.push_back({pt, pt, dir % 4});
                pt.x.a += x * d[dir][0];
                pt.x.b += x * d[dir][1];
                pt.y.a += x * d[dir][2];
                pt.y.b += x * d[dir][3];
                have2.back().r = pt;
            }
        }
//        update(have);
//        update(have2);
        if (update(have) == update(have2)) {
            cout << j << '\n';
            return;
        }
    }
}

int main() {
    ios_base::sync_with_stdio(0);
    cin.tie(0);
    cout.tie(0);
    int t = 1;
//    cin >> t;
    while (t--) {
        solve();
    }
}

/*
9
draw 1
rotate 90
draw 2
rotate 90
draw 2
rotate 90
draw 2
rotate 90
draw 1
 */